==> %5B1.20.5%2B%5D-elytrabombing-1.2.0-sources.jar: com/nad2040/elytrabombing/mixin/ItemMixin.java <==
package com.nad2040.elytrabombing.mixin;

import com.nad2040.elytrabombing.ElytraBombingMod;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1299;
import net.minecraft.class_1304;
import net.minecraft.class_1540;
import net.minecraft.class_1541;
import net.minecraft.class_1657;
import net.minecraft.class_1786;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_243;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_5712;
import net.minecraft.item.*;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1792.class)
public class ItemMixin {
	@Inject(at = @At("TAIL"), method = "use", cancellable = true)
	public void use(class_1937 world, class_1657 user, class_1268 hand, CallbackInfoReturnable<class_1271<class_1799>> cir) {
		if (user.method_6128()) {
			class_1268 other_hand = (hand == class_1268.field_5808) ? class_1268.field_5810 : class_1268.field_5808;
			class_1799 usedItemStack = user.method_5998(hand), otherItemStack = user.method_5998(other_hand);
			class_243 position = user.method_19538(), velocity = user.method_18798();
			if (ElytraBombingMod.SHOULD_LOG && !world.field_9236) {
				ElytraBombingMod.log(hand,other_hand,usedItemStack,otherItemStack,position,velocity);
			}
			if (usedItemStack.method_31574(class_1802.field_8884) && otherItemStack.method_31574(class_1802.field_8626)) {
				class_1541 tntEntity = new class_1541(world, position.field_1352, position.field_1351, position.field_1350, user);
				tntEntity.method_18799(velocity.method_1021(1.2));
				world.method_8649(tntEntity);
				// changed methods signatures to ones that are also supported in 1.18*
				world.method_8486(tntEntity.method_23317(), tntEntity.method_23318(), tntEntity.method_23321(), class_3417.field_15079, class_3419.field_15245, 1.0f, 1.0f, false);
				user.method_32875(class_5712.field_28727, tntEntity);
				if (!user.method_31549().field_7477) {
					usedItemStack.method_7970(1, user, class_1304.field_6173);
					otherItemStack.method_7934(1);
				}
				user.method_7259(class_3468.field_15372.method_14956((class_1786) (Object) this));
				cir.setReturnValue(class_1271.method_29237(user.method_5998(hand), world.method_8608()));
			} else if (usedItemStack.method_31574(class_1802.field_8782) || usedItemStack.method_31574(class_1802.field_8750) || usedItemStack.method_31574(class_1802.field_8427)) {
				class_1540 anvilEntity = new class_1540(class_1299.field_6089, world);
				anvilEntity.field_7192 = 1; // allows anvils to work on 1.18* by avoiding `(this.timeFalling++ == 0)`
				anvilEntity.method_33574(position);
				anvilEntity.method_18799(velocity.method_1021(1.2));
                anvilEntity.method_6965(1.0f, 40);
				if (usedItemStack.method_31574(class_1802.field_8782)) 		 ((ElytraBombingMod.FBEInterface) anvilEntity).setBlock(class_2246.field_10535.method_9564());
				if (usedItemStack.method_31574(class_1802.field_8750)) ((ElytraBombingMod.FBEInterface) anvilEntity).setBlock(class_2246.field_10105.method_9564());
				if (usedItemStack.method_31574(class_1802.field_8427)) ((ElytraBombingMod.FBEInterface) anvilEntity).setBlock(class_2246.field_10414.method_9564());
				anvilEntity.method_6963(anvilEntity.method_24515());
				world.method_8649(anvilEntity);
				world.method_8486(anvilEntity.method_23317(), anvilEntity.method_23318(), anvilEntity.method_23321(), class_3417.field_14727, class_3419.field_15245, 1.0f, 1.0f, false);
				if (!user.method_31549().field_7477) {
					usedItemStack.method_7934(1);
				}
				cir.setReturnValue(class_1271.method_29237(user.method_5998(hand), world.method_8608()));
			}
		}
	}
}

==> %5B1.21.5%2B%5D-elytrabombing-1.2.0-sources.jar: com/nad2040/elytrabombing/mixin/ItemMixin.java <==
package com.nad2040.elytrabombing.mixin;

import com.nad2040.elytrabombing.ElytraBombingMod;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1299;
import net.minecraft.class_1540;
import net.minecraft.class_1541;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_243;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_5712;
import net.minecraft.item.*;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;


@Mixin(class_1792.class)
public class ItemMixin {
	@Inject(at = @At("TAIL"), method = "use", cancellable = true)
	public void use(class_1937 world, class_1657 user, class_1268 hand, CallbackInfoReturnable<class_1269> cir) {
		class_1799 itemStack = user.method_5998(hand);
		if (user.method_6128()) {
			class_1268 other_hand = (hand == class_1268.field_5808) ? class_1268.field_5810 : class_1268.field_5808;
			class_1799 usedItemStack = user.method_5998(hand), otherItemStack = user.method_5998(other_hand);
			class_243 position = user.method_19538(), velocity = user.method_18798();
			if (ElytraBombingMod.SHOULD_LOG && !world.field_9236) {
				ElytraBombingMod.log(hand, other_hand, usedItemStack, otherItemStack, position, velocity);
			}
			if (usedItemStack.method_31574(class_1802.field_8884) && otherItemStack.method_31574(class_1802.field_8626)) {
				class_1541 tntEntity = new class_1541(world, position.field_1352, position.field_1351, position.field_1350, user);
				tntEntity.method_18799(velocity.method_1021(1.2));
				world.method_8649(tntEntity);
				world.method_43128(null, tntEntity.method_23317(), tntEntity.method_23318(), tntEntity.method_23321(),
					class_3417.field_15079, class_3419.field_15245, 1.0f, 1.0f);
				user.method_32875(class_5712.field_28727, tntEntity);
				if (!user.method_31549().field_7477) {
    				itemStack.method_61653(1, user);
					otherItemStack.method_7934(1);
				}
				user.method_7259(class_3468.field_15372.method_14956(class_1802.field_8884));
				cir.setReturnValue(class_1269.field_5812);
			} else if (usedItemStack.method_31574(class_1802.field_8782) || usedItemStack.method_31574(class_1802.field_8750) || usedItemStack.method_31574(class_1802.field_8427)) {
				class_1540 anvilEntity = new class_1540(class_1299.field_6089, world);
				anvilEntity.field_7192 = 1;
				anvilEntity.method_33574(position);
				anvilEntity.method_18799(velocity.method_1021(1.2));
				anvilEntity.method_6965(1.0F, 40);
				if (usedItemStack.method_31574(class_1802.field_8782)) 		 ((ElytraBombingMod.FBEInterface) anvilEntity).setBlock(class_2246.field_10535.method_9564());
				if (usedItemStack.method_31574(class_1802.field_8750)) ((ElytraBombingMod.FBEInterface) anvilEntity).setBlock(class_2246.field_10105.method_9564());
				if (usedItemStack.method_31574(class_1802.field_8427)) ((ElytraBombingMod.FBEInterface) anvilEntity).setBlock(class_2246.field_10414.method_9564());
				anvilEntity.method_6963(anvilEntity.method_24515());
				world.method_8649(anvilEntity);
				world.method_43128(null, anvilEntity.method_23317(), anvilEntity.method_23318(), anvilEntity.method_23321(),
					class_3417.field_14727, class_3419.field_15245, 1.0f, 1.0f);
				if (!user.method_31549().field_7477) {
					usedItemStack.method_7934(1);
				}
				cir.setReturnValue(class_1269.field_5812);
			}
		}
	}
}
